@@ -5,7 +5,7 @@ Term::ReadLine::Tiny - Tiny implementation of ReadLine
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -65,7 +65,7 @@ require Term::ReadKey;
 BEGIN
 {
 	require Exporter;
-	our $VERSION     = '1.02';
+	our $VERSION     = '1.03';
 	our @ISA         = qw(Exporter);
 	our @EXPORT      = qw();
 	our @EXPORT_OK   = qw();
@@ -301,7 +301,7 @@ sub readline
 				{
 					print $out $char;
 					$history->[$#$history] = $line;
-					pop $history unless defined($minline) and length($line) >= $minline;
+					pop @$history unless defined($minline) and length($line) >= $minline;
 					$result = $line;
 					last;
 				}
